summaryrefslogtreecommitdiff
path: root/source/slang/slang-lower-to-ir.cpp
diff options
context:
space:
mode:
authorYong He <yonghe@outlook.com>2022-10-27 13:08:30 -0700
committerGitHub <noreply@github.com>2022-10-27 13:08:30 -0700
commit79af29af91fb9601886d539526a4ec87bca3d74c (patch)
treed92096aff783cf83cd01673f74a91a1b1372d3ef /source/slang/slang-lower-to-ir.cpp
parent8dc9efd256bd211d8c446971f09a7c79e644b110 (diff)
Rename `[__custom_jvp]` -> `[ForwardDerivative]`. (#2473)
* Rename `[__custom_jvp]` -> `[ForwardDerivative]`. * Rename the classes. * More renaming. Co-authored-by: Yong He <yhe@nvidia.com>
Diffstat (limited to 'source/slang/slang-lower-to-ir.cpp')
-rw-r--r--source/slang/slang-lower-to-ir.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/slang/slang-lower-to-ir.cpp b/source/slang/slang-lower-to-ir.cpp
index 386cf2a21..acb7869e0 100644
--- a/source/slang/slang-lower-to-ir.cpp
+++ b/source/slang/slang-lower-to-ir.cpp
@@ -8204,10 +8204,10 @@ struct DeclLoweringVisitor : DeclVisitor<DeclLoweringVisitor, LoweredValInfo>
getBuilder()->addDecoration(irFunc, kIROp_ForceInlineDecoration);
}
// Register the value now, to avoid any possible infinite recursion when lowering CustomJVPAttribute
setGlobalValue(context, decl, LoweredValInfo::simple(findOuterMostGeneric(irFunc)));
- if (auto attr = decl->findModifier<CustomJVPAttribute>())
+ if (auto attr = decl->findModifier<ForwardDerivativeAttribute>())
{
// TODO(Sai): HACK.. we need to emit a decl-ref to handle this modifier correctly.
// If we don't move the cursor to the parent, we sometimes emit supporting
@@ -8204,10 +8204,10 @@ struct DeclLoweringVisitor : DeclVisitor<DeclLoweringVisitor, LoweredValInfo>
getBuilder()->addDecoration(irFunc, kIROp_ForceInlineDecoration);
}
- // Register the value now, to avoid any possible infinite recursion when lowering CustomJVPAttribute
+ // Register the value now, to avoid any possible infinite recursion when lowering ForwardDerivativeAttribute
setGlobalValue(context, decl, LoweredValInfo::simple(findOuterMostGeneric(irFunc)));